California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2019 - 2020 Election Dates: 1. SPECIAL ELECTION Tuesday, 3/26/19 2. SPECIAL ELECTION Tuesday, 3/26/19 3. SPECIAL ELECTION Thursday, 5/16/19 4. SPECIAL ELECTION RUNOFF Tuesday, 6/4/19 5. SPECIAL ELECTION RUNOFF Tuesday, 6/4/19 6. SPECIAL ELECTION Tuesday, 8/27/19 7. SPECIAL ELECTION RUNOFF Tuesday, 11/5/19 8. PRIMARY ELECTION Tuesday, 3/3/20 9. SPECIAL ELECTION Tuesday, 3/3/20 10. SPECIAL ELECTION RUNOFF Tuesday, 5/12/20 11. GENERAL ELECTION Tuesday, 11/3/20
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.
STATEWIDE OFFICES
GOVERNOR
NEWSOM, GAVIN
| LIEUTENANT GOVERNOR
KOUNALAKIS, ELENI
SECRETARY OF STATE
PADILLA, ALEX
| CONTROLLER
YEE, BETTY T.
TREASURER
MA, FIONA
| ATTORNEY GENERAL
BECERRA, XAVIER
SUPERINTENDENT OF PUBLIC INSTRUCTION
THURMOND, TONY
| INSURANCE COMMISSIONER
LARA, RICARDO
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
GAINES, EDWARD T
| MEMBER BOARD OF EQUALIZATION 02
COHEN, MALIA M.
MEMBER BOARD OF EQUALIZATION 03
VAZQUEZ, ANTONIO
| MEMBER BOARD OF EQUALIZATION 04
SCHAEFER, J. MICHAEL
SENATE DISTRICTS
STATE SENATE 01
DAHLE, BRIAN
| STATE SENATE 02
MC GUIRE, MIKE
STATE SENATE 03
DODD, BILL
| STATE SENATE 04
NIELSEN, JIM
STATE SENATE 05
GALGIANI, CATHLEEN
| STATE SENATE 06
PAN, RICHARD
STATE SENATE 07
GLAZER, STEVEN
| STATE SENATE 08
BORGEAS, ANDREAS
STATE SENATE 09
SKINNER, NANCY
| STATE SENATE 10
WIECKOWSKI, ROBERT
STATE SENATE 11
WIENER, SCOTT D.
| STATE SENATE 12
CABALLERO, ANNA
STATE SENATE 13
HILL, JERRY A.
| STATE SENATE 14
HURTADO, MELISSA
STATE SENATE 15
BEALL, JIM
| STATE SENATE 16
GROVE, SHANNON
STATE SENATE 17
MONNING, WILLIAM W.
| STATE SENATE 18
HERTZBERG, ROBERT
STATE SENATE 19
JACKSON, HANNAH-BETH
| STATE SENATE 20
LEYVA, CONNIE M.
STATE SENATE 21
WILK, SCOTT T.
| STATE SENATE 22
RUBIO, SUSAN
STATE SENATE 23
MORRELL, MIKE
| STATE SENATE 24
DURAZO, MARIA ELENA
STATE SENATE 25
PORTANTINO, ANTHONY
| STATE SENATE 26
ALLEN, BEN
STATE SENATE 27
STERN, HENRY
| STATE SENATE 28
MELENDEZ, MELISSA
STATE SENATE 29
CHANG, LING LING
| STATE SENATE 30
MITCHELL, HOLLY J.
STATE SENATE 31
ROTH, RICHARD D.
| STATE SENATE 32
ARCHULETA, BOB
STATE SENATE 33
GONZALEZ, LENA
| STATE SENATE 34
UMBERG, THOMAS J.
STATE SENATE 35
BRADFORD, STEVEN
| STATE SENATE 36
BATES, PATRICIA 'PAT'
STATE SENATE 37
MOORLACH, JOHN M.W.
| STATE SENATE 38
JONES, BRIAN W.
STATE SENATE 39
ATKINS, TONI G.
| STATE SENATE 40
HUESO, BEN
ASSEMBLY DISTRICTS
ASSEMBLY 01
DAHLE, MEGAN
| ASSEMBLY 02
WOOD, JIM
ASSEMBLY 03
GALLAGHER, JAMES
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA
ASSEMBLY 05
BIGELOW, FRANK
| ASSEMBLY 06
KILEY, KEVIN
ASSEMBLY 07
MC CARTY, KEVIN
| ASSEMBLY 08
COOLEY, KEN
ASSEMBLY 09
COOPER, JIM
| ASSEMBLY 10
LEVINE, MARC
ASSEMBLY 11
FRAZIER, JR., JAMES L
| ASSEMBLY 12
FLORA, HEATH
ASSEMBLY 13
EGGMAN, SUSAN
| ASSEMBLY 14
GRAYSON, TIM
ASSEMBLY 15
WICKS, BUFFY
| ASSEMBLY 16
BAUER-KAHAN, REBECCA
ASSEMBLY 17
CHIU, DAVID
| ASSEMBLY 18
BONTA, ROB
ASSEMBLY 19
TING, PHIL
| ASSEMBLY 20
QUIRK, BILL
ASSEMBLY 21
GRAY, ADAM C.
| ASSEMBLY 22
MULLIN, KEVIN C.
ASSEMBLY 23
PATTERSON, JIM
| ASSEMBLY 24
BERMAN, MARC
ASSEMBLY 25
CHU, KANSEN
| ASSEMBLY 26
MATHIS, DEVON J.
ASSEMBLY 27
KALRA, ASH
| ASSEMBLY 28
LOW, EVAN
ASSEMBLY 29
STONE, MARK
| ASSEMBLY 30
RIVAS, ROBERT
ASSEMBLY 31
ARAMBULA, JOAQUIN
| ASSEMBLY 32
SALAS JR., RUDY
ASSEMBLY 33
OBERNOLTE, JAY
| ASSEMBLY 34
FONG, VINCENT
ASSEMBLY 35
CUNNINGHAM, JORDAN
| ASSEMBLY 36
LACKEY, THOMAS W.
ASSEMBLY 37
LIMON, S. MONIQUE
| ASSEMBLY 38
SMITH, CHRISTY
ASSEMBLY 39
RIVAS, LUZ
| ASSEMBLY 40
RAMOS, JAMES
ASSEMBLY 41
HOLDEN, CHRIS
| ASSEMBLY 42
MAYES, CHAD
ASSEMBLY 43
FRIEDMAN, LAURA
| ASSEMBLY 44
IRWIN, JACQUI V.
ASSEMBLY 45
GABRIEL, JESSE
| ASSEMBLY 46
NAZARIAN, ADRIN
ASSEMBLY 47
REYES, ELOISE GOMEZ
| ASSEMBLY 48
RUBIO, BLANCA
ASSEMBLY 49
CHAU, ED
| ASSEMBLY 50
BLOOM, RICHARD
ASSEMBLY 51
CARRILLO, WENDY
| ASSEMBLY 52
RODRIGUEZ, FREDDIE
ASSEMBLY 53
SANTIAGO, MIGUEL
| ASSEMBLY 54
KAMLAGER, SYDNEY
ASSEMBLY 55
CHEN, PHILLIP
| ASSEMBLY 56
GARCIA, EDUARDO
ASSEMBLY 57
CALDERON, IAN
| ASSEMBLY 58
GARCIA, CRISTINA
ASSEMBLY 59
JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 60
CERVANTES, SABRINA
ASSEMBLY 61
MEDINA, JOSE J.
| ASSEMBLY 62
BURKE, AUTUMN
ASSEMBLY 63
RENDON, ANTHONY
| ASSEMBLY 64
GIPSON, MIKE
ASSEMBLY 65
QUIRK-SILVA, SHARON
| ASSEMBLY 66
MURATSUCHI, AL
ASSEMBLY 67
MELENDEZ, MELISSA
| ASSEMBLY 68
CHOI, STEVEN
ASSEMBLY 69
DALY, TOM
| ASSEMBLY 70
O'DONNELL, PATRICK
ASSEMBLY 71
VOEPEL, RANDY G.
| ASSEMBLY 72
DIEP, TYLER
ASSEMBLY 73
BROUGH, WILLIAM (BILL)
| ASSEMBLY 74
PETRIE-NORRIS, COTTIE
ASSEMBLY 75
WALDRON, MARIE
| ASSEMBLY 76
BOERNER HORVATH, TASHA
ASSEMBLY 77
MAIENSCHEIN, BRIAN
| ASSEMBLY 78
GLORIA, TODD
ASSEMBLY 79
WEBER, SHIRLEY
| ASSEMBLY 80
GONZALEZ, LORENA S.